@@ -57,16 +57,13 @@ class LifImage:
             Note, it is recommended to use `dims.t` instead. However, this will
             be kept for compatibility.
         scale (tuple): (scale_x, scale_y, scale_z, scale_t).
-<<<<<<< HEAD
 
-            Conversion factor: px/µm for x, y and z; sec/image for t.
-        scale_n (dict): {0: length, 1: length, 2: length...}.
+            Conversion factor: px/µm for x, y and z; images/frame for t. For
+            time, this is the duration for the entire image acquisition.
+        scale_n (dict): {1: scale_x, 2: scale_y, 3: scale_z, 4: scale_t}.
 
-            Conversion factor: px/µm for x, y and z; sec/image for t. Related
+            Conversion factor: px/µm for x, y and z; images/sec for t. Related
             to `dims_n` above.
-=======
-            Conversion factor: px/µm for x, y and z; sec/image for t.
->>>>>>> master
         bit_depth (tuple): A tuple of ints that indicates the bit depth of
             each channel in the image.
         mosaic_position (list): If the image is a mosaic (tiled), this contains
@@ -334,7 +331,7 @@ class LifImage:
         """
         if self.display_dims != (1, 2):
             raise ValueError("Atypical imaging experiment, please use "
-                             "get_extended_frame() instead of get_frame()")
+                             "get_plane() instead of get_frame()")
 
         t = int(t)
         c = int(c)
@@ -570,7 +567,7 @@ class LifFile:
                 try:
                     dim1 = int(dims[0].attrib["DimID"])
                     dim2 = int(dims[1].attrib["DimID"])
-                except AttributeError:
+                except (AttributeError, IndexError):
                     dim1 = 1
                     dim2 = 2
 
@@ -586,9 +583,15 @@ class LifFile:
                     try:
                         len_n = float(d.attrib["Length"])
 
+                        # other conversion factor for times needed
+                        # returns scale in frames per second
+                        if dim_n == 4:
+                            scale_dict[dim_n] = ((int(dims_dict[dim_n]) - 1)
+                                                 / float(len_n))
                         # Convert from meters to micrometers
-                        scale_dict[dim_n] = ((int(dims_dict[dim_n]) - 1)
-                                             / (float(len_n) * 10**6))
+                        else:
+                            scale_dict[dim_n] = ((int(dims_dict[dim_n]) - 1)
+                                                 / (float(len_n) * 10**6))
                     except (AttributeError, ZeroDivisionError):
                         scale_dict[dim_n] = None
 
